'use strict';

var React = require('react');

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol */


var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

var checkDefault = function (propVal, allowedVals, defaultVal) { return (allowedVals.includes(propVal) ? propVal : defaultVal); };

var EButtonVariant;
(function (EButtonVariant) {
    /**
     * Button variant enums
     */
    EButtonVariant["PRIMARY"] = "primary";
    EButtonVariant["SECONDARY"] = "secondary";
    EButtonVariant["TERTIARY"] = "tertiary";
    EButtonVariant["DANGER"] = "danger";
})(EButtonVariant || (EButtonVariant = {}));
var EButtonSize;
(function (EButtonSize) {
    /**
     * Button size enums
     */
    EButtonSize["SMALL"] = "small";
    EButtonSize["MEDIUM"] = "medium";
    EButtonSize["LARGE"] = "large";
})(EButtonSize || (EButtonSize = {}));
var EButtonType;
(function (EButtonType) {
    /**
     * Button type enums
     */
    EButtonType["BUTTON"] = "button";
    EButtonType["SUBMIT"] = "submit";
    EButtonType["RESET"] = "reset";
})(EButtonType || (EButtonType = {}));

var Button = function (_a) {
    var _b = _a.variant, variant = _b === void 0 ? EButtonVariant.PRIMARY : _b, _c = _a.size; _c === void 0 ? EButtonSize.SMALL : _c; var _d = _a.label, label = _d === void 0 ? "" : _d, _e = _a.btnType, btnType = _e === void 0 ? EButtonType.BUTTON : _e, disabled = _a.disabled, onClick = _a.onClick, buttonRef = _a.buttonRef, restProps = __rest(_a, ["variant", "size", "label", "btnType", "disabled", "onClick", "buttonRef"]);
    checkDefault(variant, Object.values(EButtonVariant), EButtonVariant.PRIMARY);
    var handleOnClick = function (event) {
        if (disabled)
            return;
        if (onClick)
            onClick(event);
    };
    var buttonProps = {
        type: btnType,
        onClick: handleOnClick,
        ref: buttonRef,
        disabled: disabled,
    };
    return (React.createElement("button", __assign({}, buttonProps, restProps), label));
};

exports.Button = Button;
//# sourceMappingURL=index.js.map
